/*
 * poisson2gauss.c
 *
 * Example 1 of the Debian package diploma
 *
 * Copyright (C) 1999 Andreas Franzen
 *
 * See the file copyright for details.
 *
 * This program Converts poissonian distributed noise into gaussian
 * distributed noise. 
 */
#include <stdio.h>
#include <math.h>
int main()
{
  float w;
  while (scanf("%f",&w) != EOF)
    printf("%f\n",2.0*sqrt(w+0.25109));    
/*
 * return(0) tells the make command that this program was successfully
 * terminated.
 */
  return 0;
}
