/*
 * addx.c
 *
 * Example 1 of the Debian package diploma
 *
 * Copyright (C) 1999 Andreas Franzen
 *
 * See the file copyright for details.
 *
 * This program reads 1-dimensional measurement data from stdin
 * and writes 2-dimensional measurement data to stdout.
 */
#include <stdio.h>
#include "../inc/salt.h"
int main()
{
  int i;
  double x,y;
  for(i=1;i<=stepnumber;i++)
    {
      scanf("%lf",&y);
      x=(max2theta-min2theta)/(stepnumber-1)*(i-1)+min2theta;
      printf("%f %f\n",x,y);
    }
/*
 * return(0) tells the make command that this program was successfully
 * terminated.
 */
  return(0);
}
