/*
 * salt.h
 *
 * Example 1 of the Debian package diploma
 *
 * Copyright (C) 1999 Andreas Franzen
 *
 * See the file copyright for details.
 */
#define min2theta     10.0
#define max2theta     160.7
#define stepnumber    7536
#define lambdaKalpha1 0.1788965e-9
#define lambdaKalpha2 0.1792850e-9
#define lambdaKbeta   0.162079e-9
